==> resh-5.0.0.16-py3-none-any.whl: reface/line/worker.py <==
import json
import os
import threading

from reface.core.errors import AlreadyStarted


class Worker:
    folder = ''

    def __init__(self, layer, box, module, channel):
        self.box = box
        self.module = module
        self.channel = channel
        self.layer = layer
        self.progress = 0
        self._thread = None
        self._command = None
        self.stopped = False


    @property
    def group(self): return '%s-%s-%s' % (self.box, self.module, self.channel)

    @property
    def root(self): return os.path.join('/tmp/rapida/', str(self.box), str(self.module), str(self.channel), self.folder)

    @property
    def has_thread(self): return self._thread and self._thread.is_alive()

    def run_thread(self, command, *args):
        if self.has_thread:
            raise AlreadyStarted()
        self.stopped = False
        self._thread = threading.Thread(target=self._run_thread, name=self.group, daemon=False, args=(command, *args))
        self._thread.start()

    def stop_thread(self):
        if self.has_thread:
            self.stopped = True

    def _run_thread(self, *args, **kwargs):
        raise NotImplementedError()

    def send_status(self, channel_name):
        raise NotImplementedError()

    def write(self, *path, value=None):
        file = os.path.join(self.root, *(str(part) for part in path))

        if not os.path.isdir(os.path.dirname(file)):
            os.makedirs(os.path.dirname(file), exist_ok=True)

        with open(file, mode='w') as fs:
            fs.write(json.dumps(value, indent=2))

    def read(self, *path, default=None):
        try:
            with open(os.path.join(self.root, *(str(part) for part in path)), mode='r') as fs:
                return json.loads(fs.read())
        except:
            return default

    def remove(self, *path):
        file = os.path.join(self.root, *(str(part) for part in path))
        if os.path.exists(file):
            os.remove(file)

==> resh-5.1.0.9-py3-none-any.whl: reface/line/worker.py <==
import json
import os
import threading

from reface.core.errors import AlreadyStarted


class Worker:
    folder = ''

    def __init__(self, layer, box, module, channel):
        self.box = box
        self.module = module
        self.channel = channel
        self.layer = layer
        self.progress = 0
        self._thread = None
        self._command = None
        self.stopped = False


    @property
    def group(self): return '%s-%s-%s' % (self.box, self.module, self.channel)

    @property
    def root(self): return os.path.join('/tmp/rapida/', str(self.box), str(self.module), str(self.channel), self.folder)

    @property
    def has_thread(self): return self._thread and self._thread.is_alive()

    def run_thread(self, command, *args):
        if self.has_thread:
            raise AlreadyStarted()
        self.stopped = False
        self._thread = threading.Thread(target=self._run_thread, name=self.group, daemon=False, args=(command, *args))
        self._thread.start()

    def stop_thread(self):
        if self.has_thread:
            self.stopped = True

    def _run_thread(self, *args, **kwargs):
        raise NotImplementedError()

    def send_status(self, channel_name):
        raise NotImplementedError()

    def write(self, *path, value=None):
        file = os.path.join(self.root, *(str(part) for part in path))

        if not os.path.isdir(os.path.dirname(file)):
            os.makedirs(os.path.dirname(file), exist_ok=True)

        with open(file, mode='w') as fs:
            json.dump(value, fs, indent=2)

    def read(self, *path, default=None):
        try:
            with open(os.path.join(self.root, *(str(part) for part in path)), mode='r') as fs:
                return json.load(fs)
        except:
            return default

    def remove(self, *path):
        file = os.path.join(self.root, *(str(part) for part in path))
        if os.path.exists(file):
            os.remove(file)
